# vue-auto-router

一个基于 Vite 的 Vue 路由自动生成插件。该插件会自动扫描指定目录下的 Vue 文件，并根据文件结构生成对应的路由配置。

## 功能特点

- 🚀 自动扫描指定目录下的 Vue 文件
- 📁 根据文件结构自动生成路由配置
- ⚙️ 支持自定义扫描目录和输出目录
- 🔍 支持文件排除配置
- 🔄 支持开发环境热更新
- 📦 支持最新版本的 Vite 和 Vue Router

## 安装

```bash
npm install vue-auto-router -D
# 或
yarn add vue-auto-router -D
# 或
pnpm add vue-auto-router -D
```

## 使用方法

在 `vite.config.ts` 中配置：

```typescript
import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import VueAutoRouter from 'vue-auto-router'

export default defineConfig({
  plugins: [
    vue(),
    VueAutoRouter({
      // 配置选项
      scanDir: 'src/pages/**/*.vue',  // 扫描目录
      outputDir: 'src/router/',       // 输出目录
      exclude: []                     // 排除的文件或文件夹
    })
  ]
})
```

## 配置选项

| 选项 | 类型 | 默认值 | 描述 |
|------|------|--------|------|
| scanDir | string | 'src/pages/**/*.vue' | 要扫描的目录路径 |
| outputDir | string | 'src/router/' | 路由配置文件的输出目录 |
| exclude | string[] | [] | 要排除的文件或文件夹名称 |
| layoutPath | string | '@/pages/layout/index.vue' | 布局组件的路径 |

## 目录结构示例

```
src/
  pages/
    layout/
      index.vue          # 布局组件
    comment_manager/     # 评论管理模块
      index.vue         # 列表页面
      form.vue         # 表单页面
```

生成的路由配置：

```typescript
import type { RouteRecordRaw } from 'vue-router'
import Layout from '@/pages/layout/index.vue'

const Index = () => import('@/pages/comment_manager/index.vue')
const Form = () => import('@/pages/comment_manager/form.vue')

const Router: Array<RouteRecordRaw> = [
  {
    path: '/comment_manager',
    component: Layout,
    name: 'CommentManager',
    children: [
      { path: '', component: Index, name: 'CommentManager' },
      { path: 'form', component: Form, name: 'CommentManagerForm' }
    ]
  }
]

export default Router
```

## 路由生成规则

1. **文件导入规则**
   - 匹配到的 Vue 文件会被转换为动态导入
   - 常量名使用文件名首字母大写

2. **路由路径规则**
   - 路径使用目录名全小写，以下划线分隔
   - index.vue 文件对应空路径
   - 其他文件名直接作为子路径

3. **路由名称规则**
   - 使用目录名转换为驼峰式命名
   - 子路由会附加文件名（首字母大��）

## 注意事项

1. 确保项目中已安装最新版本的 `vue-router`
2. 布局组件需要位于 `src/pages/layout/index.vue`
3. 路由配置文件会自动生成在指定的输出目录中
4. 生成的路由配置文件名为 `routes.ts`

## 开发环境

插件会在以下情况自动更新路由配置：
1. 开发服务器启动时
2. 添加新的 .vue 文件时
3. 删除 .vue 文件时
4. 项目构建开始时

## 版本要求

- Vite: 最新版本
- Vue Router: 最新版本
- Node.js: >= 16.0.0

## License

MIT
