/**
 * 插件配置选项接口
 */
export interface PluginOptions {
    /**
     * 扫描的目录路径
     * @default 'src/pages/**\/*.vue'
     */
    scanDir?: string;
    /**
     * 输出目录路径
     * @default 'src/router/'
     */
    outputDir?: string;
    /**
     * 排除的文件或文件夹
     * @default []
     */
    exclude?: string[];
    /**
     * 布局组件路径
     * @default '@/pages/layout/index.vue'
     */
    layoutPath?: string;
}
/**
 * 必需的配置选项接口
 */
export interface RequiredOptions {
    scanDir: string;
    outputDir: string;
    exclude: string[];
    layoutPath: string;
}
/**
 * 路由节点接口
 */
export interface RouteNode {
    /**
     * 路由路径
     */
    path: string;
    /**
     * 路由组件
     */
    component: string;
    /**
     * 路由名称
     */
    name: string;
    /**
     * 子路由
     */
    children?: RouteNode[];
    /**
     * 路由元信息
     */
    meta?: Record<string, any>;
}
/**
 * 导入声明接口
 */
export interface ImportDeclaration {
    /**
     * 组件名称
     */
    name: string;
    /**
     * 导入路径
     */
    path: string;
}
//# sourceMappingURL=types.d.ts.map